@@ -15,6 +15,8 @@ import { JupyterFrontEnd, JupyterFrontEndPlugin } from '@jupyterlab/application'
 import { ICommandPalette } from '@jupyterlab/apputils';
 import { LabIcon } from '@jupyterlab/ui-components';
 import { ServerConnection } from '@jupyterlab/services';
+import { heartbeat, stopHeartbeat } from './disconnectMonitor';
+import { setupDisconnectNotification } from './disconnectAlert';
 
 let homeUrl: string = '/home';
 
@@ -76,14 +78,21 @@ function activate(app: JupyterFrontEnd, palette: ICommandPalette) {
   registerCommands(app, palette);
   addRStudioIcon(app);
   addSideBar(app);
+  heartbeat(returnHome);
+  setupDisconnectNotification();
+}
+
+function deactivate() {
+  stopHeartbeat();
 }
 
 const plugin: JupyterFrontEndPlugin<void> = {
   // Initialization data for the workbench_jupyterlab extension.
   id: 'workbench-jupyterlab',
   autoStart: true,
-  requires: [ICommandPalette],
-  activate: activate,
+  requires: [ ICommandPalette ],
+  activate, 
+  deactivate
 };
 
 export default plugin;
