@@ -16,7 +16,15 @@ import { ISignal, Signal } from '@lumino/signaling';
 import React from 'react';
 
 function UseSignalComponent(props: { signal: ISignal<RStudioWorkbenchWidget, Server[]>, servers: Array<Server> }) {
-  return <UseSignal signal={props.signal} initialArgs={props.servers}>{ (_, servers) => <ProxiedServersComponent servers={servers} />}</UseSignal>
+  return (
+    <UseSignal 
+      signal={props.signal} 
+      initialArgs={props.servers}>
+      { 
+        (_, servers) => <ProxiedServersComponent servers={servers} /> 
+      }
+    </UseSignal>
+  );
 }
 
 export class RStudioWorkbenchWidget extends ReactWidget {
@@ -89,6 +97,11 @@ export class RStudioWorkbenchWidget extends ReactWidget {
   }
 
   render(): JSX.Element {
-    return (<UseSignalComponent signal={this._signal} servers={...this.getServers()} />);
+    return (
+      <UseSignalComponent 
+        signal={this._signal} 
+        servers={...this.getServers()} 
+      />
+    );
   }
 }
